@@ -98,7 +98,7 @@ class Exceptions:
 
 class NetworkManagerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html)
     """
 
@@ -111,12 +111,12 @@ class NetworkManagerClient(BaseClient):
         """
 
     def associate_customer_gateway(
-        self, *, CustomerGatewayArn: str, GlobalNetworkId: str, DeviceId: str, LinkId: str = None
+        self, *, CustomerGatewayArn: str, GlobalNetworkId: str, DeviceId: str, LinkId: str = ...
     ) -> AssociateCustomerGatewayResponseTypeDef:
         """
         Associates a customer gateway with a device and optionally, with a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_customer_gateway)
         """
 
@@ -126,7 +126,7 @@ class NetworkManagerClient(BaseClient):
         """
         Associates a link to a device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_link)
         """
 
@@ -136,13 +136,13 @@ class NetworkManagerClient(BaseClient):
         GlobalNetworkId: str,
         TransitGatewayConnectPeerArn: str,
         DeviceId: str,
-        LinkId: str = None
+        LinkId: str = ...
     ) -> AssociateTransitGatewayConnectPeerResponseTypeDef:
         """
         Associates a transit gateway Connect peer with a device, and optionally, with a
         link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#associate_transit_gateway_connect_peer)
         """
 
@@ -150,7 +150,7 @@ class NetworkManagerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#can_paginate)
         """
 
@@ -160,15 +160,15 @@ class NetworkManagerClient(BaseClient):
         GlobalNetworkId: str,
         DeviceId: str,
         ConnectedDeviceId: str,
-        LinkId: str = None,
-        ConnectedLinkId: str = None,
-        Description: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        LinkId: str = ...,
+        ConnectedLinkId: str = ...,
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateConnectionResponseTypeDef:
         """
         Creates a connection between two devices.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_connection)
         """
 
@@ -176,30 +176,30 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        AWSLocation: "AWSLocationTypeDef" = None,
-        Description: str = None,
-        Type: str = None,
-        Vendor: str = None,
-        Model: str = None,
-        SerialNumber: str = None,
-        Location: "LocationTypeDef" = None,
-        SiteId: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        AWSLocation: "AWSLocationTypeDef" = ...,
+        Description: str = ...,
+        Type: str = ...,
+        Vendor: str = ...,
+        Model: str = ...,
+        SerialNumber: str = ...,
+        Location: "LocationTypeDef" = ...,
+        SiteId: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateDeviceResponseTypeDef:
         """
         Creates a new device in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.create_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.create_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_device)
         """
 
     def create_global_network(
-        self, *, Description: str = None, Tags: Sequence["TagTypeDef"] = None
+        self, *, Description: str = ..., Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateGlobalNetworkResponseTypeDef:
         """
         Creates a new, empty global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_global_network)
         """
 
@@ -209,15 +209,15 @@ class NetworkManagerClient(BaseClient):
         GlobalNetworkId: str,
         Bandwidth: "BandwidthTypeDef",
         SiteId: str,
-        Description: str = None,
-        Type: str = None,
-        Provider: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Description: str = ...,
+        Type: str = ...,
+        Provider: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateLinkResponseTypeDef:
         """
         Creates a new link for a specified site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.create_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.create_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_link)
         """
 
@@ -225,14 +225,14 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        Description: str = None,
-        Location: "LocationTypeDef" = None,
-        Tags: Sequence["TagTypeDef"] = None
+        Description: str = ...,
+        Location: "LocationTypeDef" = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateSiteResponseTypeDef:
         """
         Creates a new site in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.create_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.create_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#create_site)
         """
 
@@ -242,7 +242,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes the specified connection in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_connection)
         """
 
@@ -250,7 +250,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_device)
         """
 
@@ -258,7 +258,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_global_network)
         """
 
@@ -266,7 +266,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_link)
         """
 
@@ -274,7 +274,7 @@ class NetworkManagerClient(BaseClient):
         """
         Deletes an existing site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#delete_site)
         """
 
@@ -284,21 +284,17 @@ class NetworkManagerClient(BaseClient):
         """
         Deregisters a transit gateway from your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#deregister_transit_gateway)
         """
 
     def describe_global_networks(
-        self,
-        *,
-        GlobalNetworkIds: Sequence[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        self, *, GlobalNetworkIds: Sequence[str] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeGlobalNetworksResponseTypeDef:
         """
         Describes one or more global networks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#describe_global_networks)
         """
 
@@ -308,7 +304,7 @@ class NetworkManagerClient(BaseClient):
         """
         Disassociates a customer gateway from a device and a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_customer_gateway)
         """
 
@@ -318,7 +314,7 @@ class NetworkManagerClient(BaseClient):
         """
         Disassociates an existing device from a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_link)
         """
 
@@ -328,21 +324,21 @@ class NetworkManagerClient(BaseClient):
         """
         Disassociates a transit gateway Connect peer from a device and link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#disassociate_transit_gateway_connect_peer)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#generate_presigned_url)
         """
 
@@ -350,15 +346,15 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        ConnectionIds: Sequence[str] = None,
-        DeviceId: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        ConnectionIds: Sequence[str] = ...,
+        DeviceId: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetConnectionsResponseTypeDef:
         """
         Gets information about one or more of your connections in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_connections)
         """
 
@@ -366,15 +362,15 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        CustomerGatewayArns: Sequence[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        CustomerGatewayArns: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetCustomerGatewayAssociationsResponseTypeDef:
         """
         Gets the association information for customer gateways that are associated with
         devices and links in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_customer_gateway_associations)
         """
 
@@ -382,15 +378,15 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        DeviceIds: Sequence[str] = None,
-        SiteId: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        DeviceIds: Sequence[str] = ...,
+        SiteId: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetDevicesResponseTypeDef:
         """
         Gets information about one or more of your devices in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_devices)
         """
 
@@ -398,15 +394,15 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        DeviceId: str = None,
-        LinkId: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        DeviceId: str = ...,
+        LinkId: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetLinkAssociationsResponseTypeDef:
         """
         Gets the link associations for a device or a link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_link_associations)
         """
 
@@ -414,17 +410,17 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        LinkIds: Sequence[str] = None,
-        SiteId: str = None,
-        Type: str = None,
-        Provider: str = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        LinkIds: Sequence[str] = ...,
+        SiteId: str = ...,
+        Type: str = ...,
+        Provider: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetLinksResponseTypeDef:
         """
         Gets information about one or more links in a specified global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_links)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_links)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_links)
         """
 
@@ -432,14 +428,14 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        SiteIds: Sequence[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        SiteIds: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetSitesResponseTypeDef:
         """
         Gets information about one or more of your sites in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_sites)
         """
 
@@ -447,15 +443,15 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        TransitGatewayConnectPeerArns: Sequence[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        TransitGatewayConnectPeerArns: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetTransitGatewayConnectPeerAssociationsResponseTypeDef:
         """
         Gets information about one or more of your transit gateway Connect peer
         associations in a global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_connect_peer_associations)
         """
 
@@ -463,15 +459,15 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        TransitGatewayArns: Sequence[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        TransitGatewayArns: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetTransitGatewayRegistrationsResponseTypeDef:
         """
         Gets information about the transit gateway registrations in a specified global
         network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#get_transit_gateway_registrations)
         """
 
@@ -479,7 +475,7 @@ class NetworkManagerClient(BaseClient):
         """
         Lists the tags for a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#list_tags_for_resource)
         """
 
@@ -489,7 +485,7 @@ class NetworkManagerClient(BaseClient):
         """
         Registers a transit gateway in your global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#register_transit_gateway)
         """
 
@@ -497,7 +493,7 @@ class NetworkManagerClient(BaseClient):
         """
         Tags a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#tag_resource)
         """
 
@@ -505,7 +501,7 @@ class NetworkManagerClient(BaseClient):
         """
         Removes tags from a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#untag_resource)
         """
 
@@ -514,14 +510,14 @@ class NetworkManagerClient(BaseClient):
         *,
         GlobalNetworkId: str,
         ConnectionId: str,
-        LinkId: str = None,
-        ConnectedLinkId: str = None,
-        Description: str = None
+        LinkId: str = ...,
+        ConnectedLinkId: str = ...,
+        Description: str = ...
     ) -> UpdateConnectionResponseTypeDef:
         """
         Updates the information for an existing connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_connection)
         """
 
@@ -530,29 +526,29 @@ class NetworkManagerClient(BaseClient):
         *,
         GlobalNetworkId: str,
         DeviceId: str,
-        AWSLocation: "AWSLocationTypeDef" = None,
-        Description: str = None,
-        Type: str = None,
-        Vendor: str = None,
-        Model: str = None,
-        SerialNumber: str = None,
-        Location: "LocationTypeDef" = None,
-        SiteId: str = None
+        AWSLocation: "AWSLocationTypeDef" = ...,
+        Description: str = ...,
+        Type: str = ...,
+        Vendor: str = ...,
+        Model: str = ...,
+        SerialNumber: str = ...,
+        Location: "LocationTypeDef" = ...,
+        SiteId: str = ...
     ) -> UpdateDeviceResponseTypeDef:
         """
         Updates the details for an existing device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.update_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.update_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_device)
         """
 
     def update_global_network(
-        self, *, GlobalNetworkId: str, Description: str = None
+        self, *, GlobalNetworkId: str, Description: str = ...
     ) -> UpdateGlobalNetworkResponseTypeDef:
         """
         Updates an existing global network.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_global_network)
         """
 
@@ -561,15 +557,15 @@ class NetworkManagerClient(BaseClient):
         *,
         GlobalNetworkId: str,
         LinkId: str,
-        Description: str = None,
-        Type: str = None,
-        Bandwidth: "BandwidthTypeDef" = None,
-        Provider: str = None
+        Description: str = ...,
+        Type: str = ...,
+        Bandwidth: "BandwidthTypeDef" = ...,
+        Provider: str = ...
     ) -> UpdateLinkResponseTypeDef:
         """
         Updates the details for an existing link.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.update_link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.update_link)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_link)
         """
 
@@ -578,13 +574,13 @@ class NetworkManagerClient(BaseClient):
         *,
         GlobalNetworkId: str,
         SiteId: str,
-        Description: str = None,
-        Location: "LocationTypeDef" = None
+        Description: str = ...,
+        Location: "LocationTypeDef" = ...
     ) -> UpdateSiteResponseTypeDef:
         """
         Updates the information for an existing site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Client.update_site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Client.update_site)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client.html#update_site)
         """
 
@@ -593,14 +589,14 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["describe_global_networks"]
     ) -> DescribeGlobalNetworksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#describeglobalnetworkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_connections"]) -> GetConnectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getconnectionspaginator)
         """
 
@@ -609,14 +605,14 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_customer_gateway_associations"]
     ) -> GetCustomerGatewayAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getcustomergatewayassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_devices"]) -> GetDevicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getdevicespaginator)
         """
 
@@ -625,21 +621,21 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_link_associations"]
     ) -> GetLinkAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_links"]) -> GetLinksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getlinkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_sites"]) -> GetSitesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#getsitespaginator)
         """
 
@@ -648,7 +644,7 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_transit_gateway_connect_peer_associations"]
     ) -> GetTransitGatewayConnectPeerAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayconnectpeerassociationspaginator)
         """
 
@@ -657,6 +653,6 @@ class NetworkManagerClient(BaseClient):
         self, operation_name: Literal["get_transit_gateway_registrations"]
     ) -> GetTransitGatewayRegistrationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/paginators.html#gettransitgatewayregistrationspaginator)
         """
